<?xml version="1.0" encoding="UTF-8"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform"
	xmlns:ijw="http://www.istandaarden.nl/ijw/3_0/basisschema/schema"
	xmlns:jw303="http://www.istandaarden.nl/ijw/3_0/jw303/schema"
	>

	<!-- iJw 3.0 TR313 version 2.1.8 (2020-10-09) -->

	<xsl:import href="../common/basis.xsl"/>
	<xsl:template match="*" mode="TR313"/>
	<xsl:template match="*" mode="check">
		<xsl:apply-templates select="*" mode="TR313"/>
	</xsl:template>

	<xsl:template match="jw303:DeclaratieFactuurBedragen" mode="TR313">
		<xsl:variable name="vTotaalDebet" select="sum(ancestor-or-self::jw303:Bericht/jw303:Clienten/jw303:Client/jw303:Prestaties/jw303:Prestatie/jw303:IngediendeBedragPrestatie/ijw:BtwBedrag[ijw:DebetCredit = 'D']/ijw:Bedrag)"/>
		<xsl:variable name="vTotaalCredit" select="sum(ancestor-or-self::jw303:Bericht/jw303:Clienten/jw303:Client/jw303:Prestaties/jw303:Prestatie/jw303:IngediendeBedragPrestatie/ijw:BtwBedrag[ijw:DebetCredit = 'C']/ijw:Bedrag)"/>
		<xsl:variable name="vSaldo" select="$vTotaalDebet - $vTotaalCredit"/>

		<!-- Controleren of BtwTotaalBedrag overeenkomt met saldo BtwBedragen -->
		<xsl:call-template name="checkimplication">
			<xsl:with-param name="pThis" select="ijw:BtwTotaalBedrag/ijw:DebetCredit" />
			<xsl:with-param name="pValue1">D</xsl:with-param>
			<xsl:with-param name="pOther" select="ijw:BtwTotaalBedrag/ijw:TotaalBedrag" />
			<xsl:with-param name="pValue2"><xsl:call-template name="formatNumber"><xsl:with-param name="pValue" select="$vSaldo" /></xsl:call-template></xsl:with-param>
			<xsl:with-param name="pExtra" select="ancestor-or-self::jw303:Bericht/jw303:Clienten/jw303:Client/jw303:Prestaties/jw303:Prestatie/jw303:IngediendeBedragPrestatie/ijw:BtwBedrag/ijw:Bedrag"/>
			<xsl:with-param name="pRule">TR313</xsl:with-param>
		</xsl:call-template>

		<!-- In het geval van Credit moet het bedrag negatief worden gemaakt -->
		<xsl:call-template name="checkimplication">
			<xsl:with-param name="pThis" select="ijw:BtwTotaalBedrag/ijw:DebetCredit" />
			<xsl:with-param name="pValue1">C</xsl:with-param>
			<xsl:with-param name="pOther" select="ijw:BtwTotaalBedrag/ijw:TotaalBedrag" />
			<xsl:with-param name="pValue2"><xsl:call-template name="formatNumber"><xsl:with-param name="pValue" select="0 - 1 * $vSaldo" /></xsl:call-template></xsl:with-param>
			<xsl:with-param name="pExtra" select="ancestor-or-self::jw303:Bericht/jw303:Clienten/jw303:Client/jw303:Prestaties/jw303:Prestatie/jw303:IngediendeBedragPrestatie/ijw:BtwBedrag/ijw:Bedrag"/>
			<xsl:with-param name="pRule">TR313</xsl:with-param>
		</xsl:call-template>
		
		<xsl:if test="$vSaldo != '0' and not(ijw:BtwTotaalBedrag/ijw:DebetCredit)">
			<xsl:call-template name="addError">
				<xsl:with-param name="pElements" select=". | ancestor-or-self::jw303:Bericht/jw303:Clienten/jw303:Client/jw303:Prestaties/jw303:Prestatie/jw303:IngediendeBedragPrestatie/ijw:BtwBedrag/ijw:Bedrag"/>
				<xsl:with-param name="pRule">TR313</xsl:with-param>
			</xsl:call-template>
		</xsl:if>
	</xsl:template>

</xsl:stylesheet>
